C
C This file is issued from the MODULEF library, but has been 
C subsequently modified
C
      SUBROUTINE FON1RR(M,IFON,X,R,ICODE)
C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C           S.P. FON1RR          (FONCTIONS INTERPRETEES)
C           -----------
C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C BUT :
C     EXECUTER UNE FONCTION AYANT 1 PARAMETRE REEL ET UN RESULTAT REEL
C
C PARAMETRES D ENTREE :
C     M       : SUPER-TABLEAU
C     IFON    : INDICE DE LA FONCTION (RETOURNE PAR FONDEF)
C     X       : PARAMETRE DE LA FONCTION
C
C PARAMETRES DE SORTIE :
C     R       : RESULTAT DE LA FONCTION
C     ICODE   : CODE DE RETOUR (VOIR LE S.P. FONERR)
C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C PROGRAMMEUR : PATRICK LAUG ; INRIA (3) 954 90 20 POSTE 508
C ......................................................................
      INTEGER M(*)
      COMMON /FONIA / IAI,IAR,IAL,IAC,IAD,IAOPN,IAOPT,IASYM,IAEXP,IAIDN
      COMMON /FONLC / LCI,LCR,LCL,LCC,LCD,LCOPN,LCOPT,LCSYM,LCEXP,LCIDN
C
      IF (IFON .LT. 0) THEN
         ICODE = 13
         GOTO 900
      END IF
      LCEXPS = LCEXP
      LCEXP  = IFON
      CALL FONNRR(M(IAI),M(IAR),M(IAL),M(IAC),M(IAD),M(IAOPN),M(IAEXP),
     +  1,X,Y,Z,R,ICODE)
      LCEXP  = LCEXPS
  900 IF (ICODE.NE.0) CALL FONERR(0,ICODE)
      END
